@@ -1,22 +1,13 @@
 from typing import Any, List
 
+from datafet.custom_types import CustomError
+from datafet.custom_types.custom_types import HttpError
 from fastapi.encoders import jsonable_encoder
 from fastapi.responses import JSONResponse
-from pydantic import BaseModel
 
-
-class HttpSuccess(BaseModel):
-    ok: str
-
-
-class CustomJsonError(BaseModel):
-    message: str
-    reasons: List[str]
-
-
-class HttpError(BaseModel):
-    statusCode: int
-    error: CustomJsonError
+#
+# PYDANTIC ERROR
+#
 
 
 def process_pydantic_validation(v):
@@ -39,7 +30,11 @@ def json_response(status_code: int, content: Any) -> JSONResponse:
 
 
 def json_error(status_code: int, message: str, reasons: List[str]) -> JSONResponse:
-    return json_response(status_code, CustomJsonError(message=message, reasons=reasons))
+    return json_response(status_code, CustomError(message=message, reasons=reasons))
+
+
+def http_error(status_code: int, message: str, reasons: List[str]) -> HttpError:
+    return HttpError(status_code, CustomError(message, reasons))
 
 
 #
@@ -57,15 +52,15 @@ def http_200_json(jsonable_content) -> JSONResponse:
 
 
 def http_400_json(message: str, reasons: List[str]) -> JSONResponse:
-    return json_response(400, CustomJsonError(message=message, reasons=reasons))
+    return json_response(400, CustomError(message=message, reasons=reasons))
 
 
 def http_403_json(message: str, reasons: List[str]) -> JSONResponse:
-    return json_response(403, CustomJsonError(message=message, reasons=reasons))
+    return json_response(403, CustomError(message=message, reasons=reasons))
 
 
 def http_404_json(message: str, reasons: List[str]) -> JSONResponse:
-    return json_response(404, CustomJsonError(message=message, reasons=reasons))
+    return json_response(404, CustomError(message=message, reasons=reasons))
 
 
 #
@@ -74,10 +69,10 @@ def http_404_json(message: str, reasons: List[str]) -> JSONResponse:
 
 
 def http_500_json(message: str, reasons: List[str]) -> JSONResponse:
-    return json_response(500, CustomJsonError(message=message, reasons=reasons))
+    return json_response(500, CustomError(message=message, reasons=reasons))
 
 
-def json_http_200_with_cookie(
+def http_200_json_with_cookie(
     content,
     key: str,
     value: str,
